universal_downloader library

Classes

DownloadProgress
Represents the progress of a download operation
DownloadResult
Represents the result of a download operation
PermissionUtils
Web stub for permission utilities Permissions are not needed on web platform
UniversalDownloader
Universal downloader that works on all Flutter platforms

Typedefs

CompleteCallback = void Function(String filePath)
Callback function for download completion
ErrorCallback = void Function(String filePath)
Callback function for download errors
ProgressCallback = void Function(DownloadProgress progress)
Callback function for download progress updates

Exceptions / Errors

CorsDownloadException
Exception thrown when CORS policy blocks downloads in web browsers
DownloadException
Exception thrown when download operations fail
FileSystemDownloadException
Exception thrown when file system operations fail during download
NetworkDownloadException
Exception thrown when network-related errors occur during download
PermissionDownloadException
Exception thrown when permission-related errors occur during download