DownloadException class
Exception thrown when download operations fail
- Implemented types
- Implementers
Constructors
- DownloadException(String message, {String? url, dynamic cause})
-
const
Properties
- cause → dynamic
-
The underlying error that caused this exception
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
The original URL that failed to download
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited