DownloadProgress class

Represents the progress of a download operation

Constructors

DownloadProgress({required int totalBytes, required int downloadedBytes, required double percentage, double? speed})
const
DownloadProgress.fromBytes({required int totalBytes, required int downloadedBytes, double? speed})
Creates a DownloadProgress instance from bytes
factory

Properties

downloadedBytes int
Bytes downloaded so far
final
hashCode int
The hash code for this object.
no setteroverride
percentage double
Progress percentage (0.0 to 100.0)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double?
Download speed in bytes per second
final
totalBytes int
Total bytes to be downloaded
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override