PermissionUtils class
Web stub for permission utilities Permissions are not needed on web platform
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getPermissionErrorMessage(
) → String - Get permission error message - not used on web
-
requestStoragePermission(
) → Future< bool> - Web doesn't need storage permissions - always returns true
-
shouldShowPermissionRationale(
) → Future< bool> - Check if we should show permission rationale - always false on web