DownloadResult class
Represents the result of a download operation
Constructors
- DownloadResult({required String filePath, required String url, required String fileName, required int totalBytes, required bool isSuccess, String? errorMessage})
-
const
- DownloadResult.failure({required String url, required String fileName, required String errorMessage})
-
Creates a failed download result
factory
- DownloadResult.success({required String filePath, required String url, required String fileName, required int totalBytes})
-
Creates a successful download result
factory
Properties
- errorMessage → String?
-
Error message if download failed
final
- fileName → String
-
The filename used for saving
final
- filePath → String
-
The file path where the file was saved
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isSuccess → bool
-
Whether the download was successful
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalBytes → int
-
Total bytes downloaded
final
- url → String
-
The original URL that was downloaded
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override