PermissionDownloadException class
Exception thrown when permission-related errors occur during download
- Inheritance
-
- Object
- DownloadException
- PermissionDownloadException
Constructors
- PermissionDownloadException(String message, {String? url, dynamic cause})
-
const
Properties
- cause → dynamic
-
The underlying error that caused this exception
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
The original URL that failed to download
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited